@@ -1296,6 +1296,7 @@ impl File {
         target_os = "openbsd",
         target_os = "cygwin",
         target_os = "illumos",
+        target_os = "aix",
         target_vendor = "apple",
     ))]
     pub fn lock(&self) -> io::Result<()> {
@@ -1321,6 +1322,7 @@ impl File {
         target_os = "cygwin",
         target_os = "solaris",
         target_os = "illumos",
+        target_os = "aix",
         target_vendor = "apple",
     )))]
     pub fn lock(&self) -> io::Result<()> {
@@ -1335,6 +1337,7 @@ impl File {
         target_os = "openbsd",
         target_os = "cygwin",
         target_os = "illumos",
+        target_os = "aix",
         target_vendor = "apple",
     ))]
     pub fn lock_shared(&self) -> io::Result<()> {
@@ -1360,6 +1363,7 @@ impl File {
         target_os = "cygwin",
         target_os = "solaris",
         target_os = "illumos",
+        target_os = "aix",
         target_vendor = "apple",
     )))]
     pub fn lock_shared(&self) -> io::Result<()> {
@@ -1374,6 +1378,7 @@ impl File {
         target_os = "openbsd",
         target_os = "cygwin",
         target_os = "illumos",
+        target_os = "aix",
         target_vendor = "apple",
     ))]
     pub fn try_lock(&self) -> Result<(), TryLockError> {
@@ -1415,6 +1420,7 @@ impl File {
         target_os = "cygwin",
         target_os = "solaris",
         target_os = "illumos",
+        target_os = "aix",
         target_vendor = "apple",
     )))]
     pub fn try_lock(&self) -> Result<(), TryLockError> {
@@ -1432,6 +1438,7 @@ impl File {
         target_os = "openbsd",
         target_os = "cygwin",
         target_os = "illumos",
+        target_os = "aix",
         target_vendor = "apple",
     ))]
     pub fn try_lock_shared(&self) -> Result<(), TryLockError> {
@@ -1473,6 +1480,7 @@ impl File {
         target_os = "cygwin",
         target_os = "solaris",
         target_os = "illumos",
+        target_os = "aix",
         target_vendor = "apple",
     )))]
     pub fn try_lock_shared(&self) -> Result<(), TryLockError> {
@@ -1490,6 +1498,7 @@ impl File {
         target_os = "openbsd",
         target_os = "cygwin",
         target_os = "illumos",
+        target_os = "aix",
         target_vendor = "apple",
     ))]
     pub fn unlock(&self) -> io::Result<()> {
@@ -1515,6 +1524,7 @@ impl File {
         target_os = "cygwin",
         target_os = "solaris",
         target_os = "illumos",
+        target_os = "aix",
         target_vendor = "apple",
     )))]
     pub fn unlock(&self) -> io::Result<()> {
@@ -2292,7 +2302,7 @@ mod cfm {
     }
 }
 #[cfg(any(target_os = "linux", target_os = "android"))]
-pub(crate) use cfm::CachedFileMetadata;
+pub(in crate::sys) use cfm::CachedFileMetadata;
 
 #[cfg(not(target_vendor = "apple"))]
 pub fn copy(from: &Path, to: &Path) -> io::Result<u64> {
